import sys

import logging
import os

def init():
    LOG_LEVEL = os.environ.get('LOG_LEVEL', 'WARNING').upper()
    logging.basicConfig(level=LOG_LEVEL)
    logFormatter = logging.Formatter("%(asctime)s [%(threadName)-12.12s] [%(levelname)-5.5s]  %(message)s")
    rootLogger = logging.getLogger()
    consoleHandler = logging.StreamHandler(sys.stdout)
    consoleHandler.setFormatter(logFormatter)
    consoleHandler.setLevel(LOG_LEVEL)
    rootLogger.addHandler(consoleHandler)



from checkov.common.models.enums import CheckResult, CheckCategories
from checkov.cloudformation.checks.resource.base_resource_check import BaseResourceCheck


class NeptuneClusterStorageEncrypted(BaseResourceCheck):
    def __init__(self):
        name = "Ensure Neptune storage is securely encrypted"
        id = "CKV_AWS_44"
        supported_resources = ['AWS::Neptune::DBCluster']
        categories = [CheckCategories.ENCRYPTION]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf):
        """
        Looks for encryption configuration of a Neptune DB cluster
        https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-neptune-dbcluster.html#cfn-neptune-dbcluster-storageencrypted
        :param conf: aws_neptune_db_cluster
        :return: <CheckResult>
        """
        if 'Properties' in conf.keys():
            if conf['Properties'].get('StorageEncrypted'):
                return CheckResult.PASSED
        return CheckResult.FAILED


check = NeptuneClusterStorageEncrypted()



from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck
from checkov.common.models.enums import CheckResult, CheckCategories


class GoogleComputeInstanceOSLogin(BaseResourceCheck):
    def __init__(self):
        name = "Ensure that no instance in the project overrides the project setting for enabling OSLogin" \
               "(OSLogin needs to be enabled in prject metadata for all instances)"
        id = "CKV_GCP_34"
        supported_resources = ['google_compute_instance']
        categories = [CheckCategories.NETWORKING]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf):
        if 'metadata' in conf.keys():
            if 'enable-oslogin'in conf['metadata'][0]:
                if not conf['metadata'][0]['enable-oslogin']:
                    return CheckResult.FAILED
        return CheckResult.PASSED



check = GoogleComputeInstanceOSLogin()



from checkov.common.models.enums import CheckResult, CheckCategories
from checkov.cloudformation.checks.resource.base_resource_check import BaseResourceCheck


class KinesisStreamEncryptionType(BaseResourceCheck):
    def __init__(self):
        name = "Ensure Kinesis Stream is securely encrypted"
        id = "CKV_AWS_43"
        supported_resources = ['AWS::Kinesis::Stream']
        categories = [CheckCategories.ENCRYPTION]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf):
        """
        Looks for KMS encryption of a Kinesis stream
        https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kinesis-stream.html#cfn-kinesis-stream-streamencryption
        :param conf: aws_kinesis_stream
        :return: <CheckResult>
        """
        if 'Properties' in conf.keys():
            if 'StreamEncryption' in conf['Properties'].keys():
                if 'EncryptionType' in conf['Properties']['StreamEncryption']:
                    encryption_type = conf['Properties']['StreamEncryption']['EncryptionType']
                    if encryption_type == 'KMS':
                        return CheckResult.PASSED
        return CheckResult.FAILED


check = KinesisStreamEncryptionType()



from checkov.common.models.enums import CheckResult, CheckCategories
from checkov.terraform.checks.resource.base_resource_value_check import BaseResourceCheck


class StorageAccountAzureServicesAccessEnabled(BaseResourceCheck):
    def __init__(self):
        name = "Ensure 'Trusted Microsoft Services' is enabled for Storage Account access"
        id = "CKV_AZURE_36"
        supported_resources = ['azurerm_storage_account', 'azurerm_storage_account_network_rules']
        categories = [CheckCategories.NETWORKING]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf):
        network_conf = [conf]
        if 'network_rules' in conf:
            network_conf = conf['network_rules']
        if 'default_action' in network_conf[0]:
            # A required field in network rules, hence if dont exist there are no network rules and Azure services
            # have access --> Pass
            if network_conf[0]['default_action'][0] == 'Allow':
                return CheckResult.PASSED
            elif 'bypass' in network_conf[0]:
                if 'AzureServices' in network_conf[0]['bypass'][0]:
                    return CheckResult.PASSED
                return CheckResult.FAILED
        return CheckResult.PASSED


check = StorageAccountAzureServicesAccessEnabled()
